.. highlight:: shell

.. _installation:

============
Installation
============

Install Sceptre::

  $ pip install sceptre

Validate installation by printing out Sceptre's version number::

  $ sceptre --version

Update Sceptre::

  $ pip install sceptre -U
